<style type="text/css">

    /* 
     * CSS Styles 
    */

    body {
        font-family: Arial, Sans-Serif;
    }

    strong {
        font-weight: bold;
    }

    a.link-presentation,
    .reviewHistory,
    #review-history,
    .documentByLine,
    .documentActions {
        display: none;
        visibility: hidden;
    }

    .documentDescription {
        padding-bottom: 0.5em;
    }

    .enumerated-link {
        text-decoration: underline;
    }

    .enumerated-links {
        border-top: solid 2px #aaaaaa;
        margin-top: 15pt;
    }

    a {
        text-decoration: none;
        color: black;
    }

    
</style>
