<style type="text/css">

    /* 
     * CSS Styles 
    */

    body {
        font-family: Arial, Sans-Serif;
    }

    strong {
        font-weight: bold;
    }

    a.link-presentation,
    .documentActions {
        display: none;
        visibility: hidden;
    }

    .enumerated-link {
        text-decoration: underline;
    }

    .enumerated-links {
        border-top: solid 2px #aaaaaa;
        margin-top: 15pt;
    }

    a {
        text-decoration: none;
        color: black;
    }

    div.bottom-left, div.bottom-right {display: none};

    @media print  {

        div.header {
            height: 30mm;
            region: top;
            display: none;
            font-size: 10px
        }

        .header table {
            width: 100%;
        }

        td.col1 {
            width: 70%;
        }

        td.col2 {
            width: 30%;
        }
        div.col2 {
            text-align: right;
        }
    }
    
</style>
